summaryrefslogtreecommitdiff
path: root/editor/dependency_editor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'editor/dependency_editor.cpp')
-rw-r--r--editor/dependency_editor.cpp6
1 files changed, 5 insertions, 1 deletions
diff --git a/editor/dependency_editor.cpp b/editor/dependency_editor.cpp
index 5c35a91fea..5df2b687cc 100644
--- a/editor/dependency_editor.cpp
+++ b/editor/dependency_editor.cpp
@@ -496,7 +496,8 @@ void DependencyRemoveDialog::ok_pressed() {
res->set_path("");
}
// If the file we are deleting for e.g. the main scene or default environment, we must clear its definition in Project Settings.
if (files_to_delete[i] == ProjectSettings::get_singleton()->get("application/config/icon")) {
ProjectSettings::get_singleton()->set("application/config/icon", "");
}
@@ -518,6 +519,9 @@ void DependencyRemoveDialog::ok_pressed() {
if (files_to_delete[i] == ProjectSettings::get_singleton()->get("gui/theme/custom_font")) {
ProjectSettings::get_singleton()->set("gui/theme/custom_font", "");
}
+ if (files_to_delete[i] == ProjectSettings::get_singleton()->get("audio/default_bus_layout")) {
+ ProjectSettings::get_singleton()->set("audio/default_bus_layout", "");
+ }
String path = OS::get_singleton()->get_resource_dir() + files_to_delete[i].replace_first("res://", "/");
print_verbose("Moving to trash: " + path);
@@ -496,7 +496,8 @@ void DependencyRemoveDialog::ok_pressed() {
res->set_path("");
}
- // If the file we are deleting for e.g. the main scene or default environment, we must clear its definition in Project Settings.
+ // If the file we are deleting for e.g. the main scene, default environment,
+ // or audio bus layout, we must clear its definition in Project Settings.
if (files_to_delete[i] == ProjectSettings::get_singleton()->get("application/config/icon")) {
ProjectSettings::get_singleton()->set("application/config/icon", "");